@@ -76,6 +76,12 @@ def remove_dir(path):
         shutil.rmtree(path)
 
 
+# will remove a bunch of files in a list
+def remove_files(file_list):
+    for file in file_list:
+        remove_file(file)
+
+
 # will copy a directory
 def copy_dir(src, dst):
     from distutils.dir_util import copy_tree
@@ -131,7 +137,7 @@ def search_files(path_to_search, full_name=None, prefix=None, suffix=None, by_ex
             search_queue += f'*{by_extension}'
 
     for filename in Path(path_to_search).glob(search_queue):
-        files.append(filename)
+        files.append(str(filename))
     return files
 
 
@@ -203,7 +209,12 @@ def remove_all_files_with_extension(path, ext):
     if ext[0] == '.':
         ext = ext[1:]
     for f in glob.glob(path + "/*." + ext):
-        os.remove(f)
+        remove_file(f)
+
+
+# will remove a single file
+def remove_file(file):
+    os.remove(file)
 
 
 # will check if line exists in a file
